#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <bastard.h>
#include <bdb.h>
#include <extension.h>


/* OUTOUT BINARY: create binary image of (patched) target */
int plugin_main( FILE *f )
{
	int fd, count;
	unsigned char buf[512];
	struct DISASM_TGT *target = env_get_target();

	fd = fileno( f );
	if ( fd > 2 ) {
		/* do not write to STDOUT/ERR :) */
		lseek( target->fd, 0, SEEK_SET );
		while ( (count = read(target->fd, buf, 512)) > 0 ) {
			write( fd, buf, count );
		}
	}
	return (1);
}
